==> maleo_core-0.1.99-py3-none-any.whl: maleo_core/clients/maleo_suite/maleo_shared/http/controllers/service.py <==
from maleo_core.clients.maleo_suite.maleo_shared.http.manager import MaleoSharedHTTPClientManager
from maleo_core.models.base.transfers.results.clients.http.controller import BaseHTTPClientControllerResults
from maleo_core.models.maleo_shared.transfers.parameters.client.service import MaleoSharedServiceClientParameters
from maleo_core.models.maleo_shared.transfers.parameters.general.service import MaleoSharedServiceGeneralParameters

class MaleoSharedServiceHTTPController:
    @staticmethod
    async def get_services(parameters:MaleoSharedServiceClientParameters.Get) -> BaseHTTPClientControllerResults:
        """Fetch services from maleo-shared"""
        async with MaleoSharedHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSharedHTTPClientManager._base_url}/v1/services/"

            query_parameters = MaleoSharedServiceClientParameters.GetQuery.model_validate(parameters.model_dump())
            params = query_parameters.to_query_params()

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def get_service(parameters:MaleoSharedServiceGeneralParameters.GetSingle) -> BaseHTTPClientControllerResults:
        """Fetch service from maleo-shared"""
        async with MaleoSharedHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSharedHTTPClientManager._base_url}/v1/services/"
            if parameters.identifier == MaleoSharedServiceGeneralParameters.GetSingleIdentifiers.ID:
                url += f"{parameters.value}"
            else:
                url += f"{parameters.identifier.value}/{parameters.value}"

            #* Construct query parameters
            params = {}
            if parameters.is_deleted is not None:
                params["is_deleted"] = str(parameters.is_deleted).lower()
            if parameters.is_active is not None:
                params["is_active"] = str(parameters.is_active).lower()

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

==> maleo_core-0.2.20-py3-none-any.whl: maleo_core/clients/maleo_suite/maleo_shared/http/controllers/service.py <==
from maleo_core.clients.maleo_suite.maleo_shared.http.manager import MaleoSharedHTTPClientManager
from maleo_core.models.base.transfers.results.clients.http.controller import BaseHTTPClientControllerResults
from maleo_core.models.maleo_suite.maleo_shared.transfers.parameters.client.service import MaleoSharedServiceClientParameters
from maleo_core.models.maleo_suite.maleo_shared.transfers.parameters.general.service import MaleoSharedServiceGeneralParameters

class MaleoSharedServiceHTTPController:
    @staticmethod
    async def get_services(parameters:MaleoSharedServiceClientParameters.Get) -> BaseHTTPClientControllerResults:
        """Fetch services from maleo-shared"""
        async with MaleoSharedHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSharedHTTPClientManager._base_url}/v1/services/"

            query_parameters = MaleoSharedServiceClientParameters.GetQuery.model_validate(parameters.model_dump())
            params = query_parameters.to_query_params()

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)

    @staticmethod
    async def get_service(parameters:MaleoSharedServiceGeneralParameters.GetSingle) -> BaseHTTPClientControllerResults:
        """Fetch service from maleo-shared"""
        async with MaleoSharedHTTPClientManager.get() as client:
            #* Define URL
            url = f"{MaleoSharedHTTPClientManager._base_url}/v1/services/"
            if parameters.identifier == MaleoSharedServiceGeneralParameters.Identifiers.ID:
                url += f"{parameters.value}"
            else:
                url += f"{parameters.identifier.value}/{parameters.value}"

            #* Construct query parameters
            params = {}
            if parameters.is_deleted is not None:
                params["is_deleted"] = str(parameters.is_deleted).lower()
            if parameters.is_active is not None:
                params["is_active"] = str(parameters.is_active).lower()

            #* Get Response
            response = await client.get(url=url, params=params)
            return BaseHTTPClientControllerResults(response=response)
